@@ -3,25 +3,21 @@ from subprocess import check_output
 from os.path import isfile, join
 from .lib.utils import Color, symbol_ssh, separator, element_spacing
 from zshpower.utils.check import is_tool
+from zshpower.utils.process import shell_command
 
 
 def docker_status():
-    from subprocess import Popen, PIPE
-
     cmd = """
     state=$(docker info > /dev/null 2>&1)
     if [[ $? -ne 0 ]]; then
         echo "disabled"
     fi
     """
-    p = Popen(cmd, shell=True, stdout=PIPE, stderr=PIPE, universal_newlines=True)
-    output, err = p.communicate()
-    return output.replace("\n", ""), err
+    return shell_command(cmd)[0]
 
 
-class Docker(Color):
+class Docker:
     def __init__(self, config):
-        super().__init__()
         self.config = config
         self.dockerfile = join(getcwd(), "Dockerfile")
         self.docker_compose = join(getcwd(), "docker-compose.yml")
@@ -49,20 +45,17 @@ class Docker(Color):
         return f"{'.'.join(docker_v)}{space_elem}"
 
     def __str__(self):
-        if (
-            is_tool("docker")
-            and self.docker_version_enable
-            and not docker_status()[0] == "disabled"
-        ):
-            if isfile(self.dockerfile) or isfile(self.docker_compose):
-                docker_prefix = (
-                    f"{Color(self.docker_prefix_color)}"
-                    f"{self.docker_prefix_text}{Color().NONE}"
-                )
-                docker_export = (
-                    f"{separator(self.config)}{docker_prefix}"
-                    f"{Color(self.docker_color)}"
-                    f"{self.docker_symbol}{self.get_version()}{Color().NONE}"
-                )
-                return str(docker_export)
+        if self.docker_version_enable:
+            if not docker_status() == "disabled":
+                if isfile(self.dockerfile) or isfile(self.docker_compose):
+                    docker_prefix = (
+                        f"{Color(self.docker_prefix_color)}"
+                        f"{self.docker_prefix_text}{Color().NONE}"
+                    )
+                    docker_export = (
+                        f"{separator(self.config)}{docker_prefix}"
+                        f"{Color(self.docker_color)}"
+                        f"{self.docker_symbol}{self.get_version()}{Color().NONE}"
+                    )
+                    return str(docker_export)
         return ""
