@@ -4,9 +4,8 @@ from .lib.utils import Color
 from .lib.utils import symbol_ssh, git_status, element_spacing, separator
 
 
-class Git(Color):
+class Git:
     def __init__(self, config, icon_space=" "):
-        super().__init__()
         self.config = config
         self.git_enable = config["git"]["enable"]
         self.git_symbol = symbol_ssh(config["git"]["symbol"], "git:")
@@ -98,7 +97,7 @@ class Git(Color):
         self.icons["UD"] = self.icons["UU"]
 
     def __str__(self):
-        if isdir(join(getcwd(), ".git")):
+        if self.git_enable and isdir(join(getcwd(), ".git")):
             status_git = git_status(porcelain=True)
             status_git_text = git_status()
             branch_current = git_status(branch=True)
