@@ -12,9 +12,8 @@ def get_virtualenv_name():
     return ""
 
 
-class Virtualenv(Color):
+class Virtualenv:
     def __init__(self, config):
-        super().__init__()
         self.config = config
         self.venv_enable = config["virtualenv"]["enable"]
         self.venv_symbol = symbol_ssh(config["virtualenv"]["symbol"], "")
@@ -29,7 +28,7 @@ class Virtualenv(Color):
         involved_prefix = ""
         involved_suffix = ""
 
-        if "VIRTUAL_ENV" in os_environ and self.venv_enable:
+        if self.venv_enable and "VIRTUAL_ENV" in os_environ:
             env_prefix = (
                 f"{Color(self.venv_prefix_color)}"
                 f"{self.venv_prefix_text}{Color().NONE}"
